1.0.0 API documentation: extended_min_max.hpp File Reference

| 1.0.0 API documentation

Functions
extended_min_max.hpp File Reference

GLM_GTX_extended_min_max More...

Go to the source code of this file.

## Functions
template<typename T , template< typename > class C>
GLM_FUNC_DECL C< T > | max (C< T > const &x, C< T > const &y, C< T > const &z)
| Return the maximum component-wise values of 3 inputs. More...
template<typename T , template< typename > class C>
GLM_FUNC_DECL C< T > | max (C< T > const &x, C< T > const &y, C< T > const &z, C< T > const &w)
| Return the maximum component-wise values of 4 inputs. More...
template<typename T , template< typename > class C>
GLM_FUNC_DECL C< T > | max (C< T > const &x, typename C< T >::T const &y, typename C< T >::T const &z)
| Return the maximum component-wise values of 3 inputs. More...
template<typename T , template< typename > class C>
GLM_FUNC_DECL C< T > | max (C< T > const &x, typename C< T >::T const &y, typename C< T >::T const &z, typename C< T >::T const &w)
| Return the maximum component-wise values of 4 inputs. More...
template<typename T >
GLM_FUNC_DECL T | max (T const &x, T const &y, T const &z)
| Return the maximum component-wise values of 3 inputs. More...
template<typename T >
GLM_FUNC_DECL T | max (T const &x, T const &y, T const &z, T const &w)
| Return the maximum component-wise values of 4 inputs. More...
template<typename T , template< typename > class C>
GLM_FUNC_DECL C< T > | min (C< T > const &x, C< T > const &y, C< T > const &z)
| Return the minimum component-wise values of 3 inputs. More...
template<typename T , template< typename > class C>
GLM_FUNC_DECL C< T > | min (C< T > const &x, C< T > const &y, C< T > const &z, C< T > const &w)
| Return the minimum component-wise values of 4 inputs. More...
template<typename T , template< typename > class C>
GLM_FUNC_DECL C< T > | min (C< T > const &x, typename C< T >::T const &y, typename C< T >::T const &z)
| Return the minimum component-wise values of 3 inputs. More...
template<typename T , template< typename > class C>
GLM_FUNC_DECL C< T > | min (C< T > const &x, typename C< T >::T const &y, typename C< T >::T const &z, typename C< T >::T const &w)
| Return the minimum component-wise values of 4 inputs. More...
template<typename T >
GLM_FUNC_DECL T | min (T const &x, T const &y, T const &z)
| Return the minimum component-wise values of 3 inputs. More...
template<typename T >
GLM_FUNC_DECL T | min (T const &x, T const &y, T const &z, T const &w)
| Return the minimum component-wise values of 4 inputs. More...

## Detailed Description

GLM_GTX_extended_min_max

See also
  Core features (dependence)

Definition in file extended_min_max.hpp.